summaryrefslogtreecommitdiffhomepage
path: root/applications/luci-app-ddns/htdocs/luci-static/resources/view
diff options
context:
space:
mode:
authorPaul Donald <newtwen+github@gmail.com>2024-09-04 16:32:19 +0200
committerPaul Donald <newtwen+github@gmail.com>2024-09-04 16:32:19 +0200
commite8e6c1a0c0dabeb985467907f1e5ee7871e63b38 (patch)
treeaa8b8a3191170b8b6c2454f2a952ffb7789f3fdc /applications/luci-app-ddns/htdocs/luci-static/resources/view
parent96be7a3eb95847a15e273100e82afdcb99a3ee02 (diff)
luci-app-ddns: string fixes (sp/gr)
Signed-off-by: Paul Donald <newtwen+github@gmail.com>
Diffstat (limited to 'applications/luci-app-ddns/htdocs/luci-static/resources/view')
-rw-r--r--applications/luci-app-ddns/htdocs/luci-static/resources/view/ddns/overview.js52
1 files changed, 26 insertions, 26 deletions
diff --git a/applications/luci-app-ddns/htdocs/luci-static/resources/view/ddns/overview.js b/applications/luci-app-ddns/htdocs/luci-static/resources/view/ddns/overview.js
index c1bb19f2a3..ea16ee3853 100644
--- a/applications/luci-app-ddns/htdocs/luci-static/resources/view/ddns/overview.js
+++ b/applications/luci-app-ddns/htdocs/luci-static/resources/view/ddns/overview.js
@@ -59,12 +59,12 @@ return view.extend({
services: {},
/*
- * Services list is gen by 3 different source:
+ * Services list is generated by 3 different sources:
* 1. /usr/share/ddns/default contains the service installed by opkg
* 2. /usr/share/ddns/custom contains any service installed by the
- * user or the ddns script (for example when service are
+ * user or the ddns script (for example when services are
* downloaded)
- * 3. /usr/share/ddns/list contains all the service that can be
+ * 3. /usr/share/ddns/list contains all the services that can be
* downloaded by using the ddns script ('service on demand' feature)
*
* (Special services that requires a dedicated package ARE NOT
@@ -101,10 +101,10 @@ return view.extend({
},
/*
* Check if the service is supported.
* If the script doesn't find any json assume a 'service on demand' install.
* If a json is found check if the ip type is supported.
* Invalidate the service_name if is not supported.
*/
handleCheckService : function(s, service_name, ipv6, ev, section_id) {
@@ -399,7 +399,7 @@ return view.extend({
// Advanced Configuration Section
o = s.taboption('global', form.Flag, 'upd_privateip', _("Allow non-public IP's"));
- o.description = _("Non-public and by default blocked IP's") + ':'
+ o.description = _("Non-public and by default blocked IPs") + ':'
+ '<br /><strong>IPv4: </strong>'
+ '0/8, 10/8, 100.64/10, 127/8, 169.254/16, 172.16/12, 192.168/16'
+ '<br /><strong>IPv6: </strong>'
@@ -417,13 +417,13 @@ return view.extend({
o.rmempty = true;
o = s.taboption('global', form.Value, 'ddns_rundir', _('Status directory'));
- o.description = _('Directory contains PID and other status information for each running section.');
+ o.description = _('Contains PID and other status information for each running section.');
o.default = "/var/run/ddns";
o.optional = true;
o.rmempty = true;
o = s.taboption('global', form.Value, 'ddns_logdir', _('Log directory'));
- o.description = _('Directory contains Log files for each running section.');
+ o.description = _('Contains Log files for each running section.');
o.default = "/var/log/ddns";
o.optional = true;
o.rmempty = true;
@@ -449,12 +449,12 @@ return view.extend({
}
- o = s.taboption('global', form.Value, 'cacert', _('Ca Certs path'));
- o.description = _('Ca Certs path that will be used to download services data. Set IGNORE to skip certificate validation.');
+ o = s.taboption('global', form.Value, 'cacert', _('CA Certs path'));
+ o.description = _('CA certificates path that will be used to download services data. Set IGNORE to skip certificate validation.');
o.placeholder = 'IGNORE';
o = s.taboption('global', form.Value, 'services_url', _('Services URL Download'));
- o.description = _('Url used to download services file. By default is the master openwrt ddns package repo.');
+ o.description = _('Source URL for services file. Defaults to the master openwrt ddns package repo.');
o.placeholder = 'https://raw.githubusercontent.com/openwrt/packages/master/net/ddns-scripts/files';
// DDns services
@@ -523,7 +523,7 @@ return view.extend({
service_name.validate = function(section_id, value) {
if (value == '') return _("Select a service");
if (s2.service_supported == null) return _("Checking the service support...");
- if (!s2.service_supported) return _("Service doesn't support this ip type");
+ if (!s2.service_supported) return _("Service doesn't support this IP type");
return true;
};
@@ -611,7 +611,7 @@ return view.extend({
o = s.taboption('basic', form.Flag, 'enabled',
_('Enabled'),
- _("If this service section is disabled it could not be started.")
+ _("If this service section is disabled it will not be started.")
+ "<br />" +
_("Neither from LuCI interface nor from console."));
o.modalonly = true;
@@ -620,7 +620,7 @@ return view.extend({
o = s.taboption('basic', form.Value, 'lookup_host',
_("Lookup Hostname"),
- _("Hostname/FQDN to validate, if IP update happen or necessary"));
+ _("Hostname/FQDN to validate, whether an IP update is necessary"));
o.rmempty = false;
o.placeholder = "myhost.example.com";
o.datatype = 'and(minlength(3),hostname("strict"))';
@@ -657,7 +657,7 @@ return view.extend({
if (value == '') return _("Select a service");
if (s.service_available == null) return _("Checking the service support...");
if (!s.service_available) return _('Service not installed');
- if (!s.service_supported) return _("Service doesn't support this ip type");
+ if (!s.service_supported) return _("Service doesn't support this IP type");
return true;
};
@@ -677,7 +677,7 @@ return view.extend({
if (!s.service_supported) {
o = s.taboption('basic', form.DummyValue, '_not_supported', '&nbsp');
o.cfgvalue = function () {
- return _("Service doesn't support this ip type")
+ return _("Service doesn't support this IP type")
};
}
@@ -699,9 +699,9 @@ return view.extend({
o = s.taboption('basic', form.Value, 'update_url',
_("Custom update-URL"),
- _("Update URL to be used for updating your DDNS Provider.")
+ _("Update URL for updating your DDNS Provider.")
+ "<br />" +
- _("Follow instructions you will find on their WEB page."));
+ _("Follow instructions found on their WEB page."));
o.modalonly = true;
o.rmempty = true;
o.optional = true;
@@ -710,7 +710,7 @@ return view.extend({
var other = this.section.children.filter(function(o) { return o.option == 'update_script' })[0].formvalue(section_id);
if ((value == "" && other == "") || (value != "" && other != "")) {
- return _("Insert a Update Script OR a Update URL");
+ return _("Insert an Update Script OR an Update URL");
}
return true;
@@ -718,7 +718,7 @@ return view.extend({
o = s.taboption('basic', form.Value, 'update_script',
_("Custom update-script"),
- _("Custom update script to be used for updating your DDNS Provider."));
+ _("Custom update script for updating your DDNS Provider."));
o.modalonly = true;
o.rmempty = true;
o.optional = true;
@@ -727,7 +727,7 @@ return view.extend({
var other = this.section.children.filter(function(o) { return o.option == 'update_url' })[0].formvalue(section_id);
if ((value == "" && other == "") || (value != "" && other != "")) {
- return _("Insert a Update Script OR a Update URL");
+ return _("Insert an Update Script OR an Update URL");
}
return true;
@@ -1006,14 +1006,14 @@ return view.extend({
force_to_sec = _this.time_res[force_unit || 'minutes'] * formvalue;
if (force_to_sec != 0 && force_to_sec < check_to_sec)
- return _("Values lower 'Check Interval' except '0' are not supported");
+ return _("Values lower than 'Check Interval' except '0' are invalid");
return true;
};
o = s.taboption("timer", form.ListValue, "force_unit",
_('Force Unit'),
- _("Interval unit to force updates sent to DDNS Provider."));
+ _("Interval unit for forced updates sent to DDNS Provider."));
o.modalonly = true;
o.optional = true;
o.default = "minutes"
@@ -1033,7 +1033,7 @@ return view.extend({
o = s.taboption("timer", form.Value, "retry_interval",
_("Error Retry Interval"),
- _("The interval between which each successive retry commences."));
+ _("The interval between which each subsequent retry commences."));
o.placeholder = "60";
o.optional = true;
o.modalonly = true;
@@ -101,10 +101,10 @@ return view.extend({
},
/*
- * Check if the service is supported.
- * If the script doesn't find any json assume a 'service on demand' install.
- * If a json is found check if the ip type is supported.
- * Invalidate the service_name if is not supported.
+ * Check whether or not the service is supported.
+ * If the script doesn't find any JSON, assume a 'service on demand' install.
+ * If a JSON is found, check if the IP type is supported.
+ * Invalidate the service_name if it is not supported.
*/
handleCheckService : function(s, service_name, ipv6, ev, section_id) {